@@ -1,6 +1,6 @@
 package Acme::CPANAuthors::ToBeLike;
 BEGIN {
-  $Acme::CPANAuthors::ToBeLike::VERSION = '0.10';
+  $Acme::CPANAuthors::ToBeLike::VERSION = '0.12';
 }
 
 #ABSTRACT: BeLike other CPAN Authors
@@ -9,6 +9,7 @@ use strict;
 use warnings;
 
 use Acme::CPANAuthors::Register (
+  ALEXBIO => q[Alessandro Ghedini],
   AVAR => q[AEvar Arnfjord Bjarmason],
   BINGOS => q[Chris Williams],
   BLUEFEET => q[Aran Clary Deltac],
@@ -22,7 +23,9 @@ use Acme::CPANAuthors::Register (
   LESPEA => q[Adam Lesperance],
   MARCEL => q[Marcel Gruenauer],
   MELO => q[Pedro Melo],
+  MSCHOUT => q[Michael Schout],
   RJBS => q[Ricardo SIGNES],
+  SARTAK => q[Shawn M Moore],
   SHARYANTO => q[Steven Haryanto],
   YANICK => q[Yanick Champoux],
 );
@@ -39,7 +42,7 @@ Acme::CPANAuthors::ToBeLike - BeLike other CPAN Authors
 
 =head1 VERSION
 
-version 0.10
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -62,6 +65,7 @@ It is currently statically generated information, I hope to make it dynamic in t
 
 =head1 CONTAINED AUTHORS
 
+  ALEXBIO => q[Alessandro Ghedini],
   AVAR => q[AEvar Arnfjord Bjarmason],
   BINGOS => q[Chris Williams],
   BLUEFEET => q[Aran Clary Deltac],
@@ -75,7 +79,9 @@ It is currently statically generated information, I hope to make it dynamic in t
   LESPEA => q[Adam Lesperance],
   MARCEL => q[Marcel Gruenauer],
   MELO => q[Pedro Melo],
+  MSCHOUT => q[Michael Schout],
   RJBS => q[Ricardo SIGNES],
+  SARTAK => q[Shawn M Moore],
   SHARYANTO => q[Steven Haryanto],
   YANICK => q[Yanick Champoux],
 
